==> appfs-21.02.tar.gz: usr/local/www/berogui/index.php <==
<?php

# check if session is valid
require_once('/usr/local/www/berogui/includes/session.php');

function hwchange ($ba,$li,$newlif){
	$type='none';
	$q = $ba->select("select type from isdn where type!='bf2t1e1' and type!='bf1t1e1' and type!='bf4t1e1' and lif='".$li."' group by type "
		. "union select type from analog where lif='".$li."' group by type "
		. "union select type from gsm where lif='".$li."' group by type "
		. "union select type from lte where lif='".$li."' group by type "
		. "union select type from cas where lif='".$li."' group by type order by type;");
            while ($ent = $ba->fetch_array($q)) {
                 $type=$ent['type'];
	    }

	return $type!=$newlif;
}

if (PHP_VERSION == '5.2.6' && !is_file("/tmp/gui_ready")){
	print("<html><head><title>beroNet Gateway</title></head>"
		. "<body><div style='text-align:center'>"
		. "<img src='./includes/images/waitlogo.gif' title='Wait image'>"
		. "<p>Please wait until the start process has finished completely.</p>"
		. "</div>"
		. "<script type='text/javascript'>"
		. "window.setTimeout('location.reload()',5000);"
        . "</script></body></html>");
	return;
}

function liAssignment ($ba,$table,$li){
	$r = $ba->select("select distinct(type) from $table where lif='$li'");
	return sqlite_fetch_single($r);
}

require_once('includes/variables.php');
include_once("/usr/www/include/SQLite2ToSQLite3.php");
require_once('includes/password_func.php');

/* require 'misc/database.php' leads to also load the Helper Class ... why ?? */
require_once('misc/database.php');

// check the request uri entry to forbid <script> and <javascript> flags
if (!Helper::checkInputData('uri', $_SERVER['REQUEST_URI'])) {
	$_SESSION['forbidden_request'] = true;
	include('/usr/local/www/berogui/includes/session.php');
}

$class = ((isset($_GET['m']) && $_GET['m'] !== '') ? Helper::sanitizeGet($_GET['m'], 'm') : 'State');

$_GET['m'] = $class;
require_once("/usr/local/www/berogui/modules/$class/$class.php");
$instance=new $class($class, $_GET, $_POST, $_SESSION);
print $instance->display();


/* Überprüfung ab eine Hardwareänderung stattgefunden hat,
 * Der Benutzer wird durch eine Meldung darauf hingewiesen,
 * dass ein Factory reset erforderlich ist
 */

	$ba = new beroAri();
        $revision = Helper::getRevision();
	$lif = Helper::getLif();

	if (in_array($revision, array('1.8', '1.80')) && (in_array($li[0], array('bf2S02FXS', 'bf4FXS')) || in_array($li[1], array('bf2S02FXS', 'bf4FXS')))) {
		print ("<script>document.getElementById('hardware_ch').innerHTML+=\" ".HARDWARE_SUPPORT_DIS."\";</script>");
	}

	for ($i = 0; $i < Helper::getLifCount(); $i++) {
		if (hwchange($ba, $i, $lif[$i])) {
			print("<script>document.getElementById('hardware_ch').innerHTML=\"".HARDWARE_CHANGED_DIS."\";</script>");
		}
	}

if (Helper::getResetJumper() == 1){
	print ("<script>document.getElementById('reset_jumper').innerHTML=\"".RESET_JUMPER_GUI_DIS."\";</script>");
}

$destination = base64_encode("/app/berogui/index.php?m=$class");
ob_start();
?>
	<script>
		function session(){
			$.ajax({
				url: 'misc/checkSession.php?return=true',
				timeout: 1000,
				success: function(data) {
					var url = data;
					if (url!='')
						window.location=url;
				},
				error: function(res) {
					if (res.status == 408) {
						window.location.href = './includes/login.php?reason=sess_expd&destination=<?php echo $destination; ?>';
					}
				},
			});
		}
	</script>
<?php
print ob_get_clean();

require_once('/usr/fallback/beroConf.php');
$bc = new beroConf('root');

if (strlen($bc->get('root', 'trace-state')) > 0 && $class != 'FulltraceGui') {
	ob_start();
?>
	<script>
		var intervalId = setInterval(debugFilesNotification, 1000);
		function debugFilesNotification() {
			$.ajax({
				data: {
					action: 'notif',
				},
				error: function(res) {
					if (res.status == 400) {
						$('#ajaxErrors').html('<?php echo AJAX_ERRORS_BAD_REQUEST; ?>');
					}
					else if (res.status == 408) {
						window.location.href = './includes/login.php?reason=sess_expd&destination=<?php echo $destination; ?>';
					}
				},
				success: function(res) {
					var state = JSON.parse(res);
					if (typeof state.show !== 'undefined') {
						if (state.show == '1') {
							$('h1').css('margin-bottom', '-10px');
							$('#showNotif').attr('style', 'position:relative;left:69%;top:-25%;color:red;');
							$('#showNotif').html("<?php echo FULL_TRACE_DEBUGFILES_NOTIF; ?>");
							clearInterval(intervalId);
							window.setInterval(session, 10000);
							return;
						}
					}
				},
				timeout: 1000,
				type: 'POST',
				url: 'modules/FulltraceGui/fulltracegui_ajax.php',
			});
		}
	</script>
<?php
}
else {
	ob_start();
?>
	<script>
		window.setInterval(session, 60000);
	</script>
<?php
}
print ob_get_clean();


chdir('/usr/local/www/berogui');
$helpPath="./includes/images/";
require_once('includes/footer.php');
?>

==> appfs-24.01.02-rc04.tar.gz: usr/local/www/berogui/index.php <==
<?php

# check if session is valid
require_once('/usr/local/www/berogui/includes/session.php');

function hwchange ($ba,$li,$newlif){
	$type='none';
	$q = $ba->select("select type from isdn where type!='bf2t1e1' and type!='bf1t1e1' and type!='bf4t1e1' and lif='".$li."' group by type "
		. "union select type from analog where lif='".$li."' group by type "
		. "union select type from gsm where lif='".$li."' group by type "
		. "union select type from lte where lif='".$li."' group by type "
		. "union select type from cas where lif='".$li."' group by type order by type;");
            while ($ent = $ba->fetch_array($q)) {
                 $type=$ent['type'];
	    }

	return $type!=$newlif;
}

function liAssignment ($ba,$table,$li){
	$r = $ba->select("select distinct(type) from $table where lif='$li'");
	return sqlite_fetch_single($r);
}

if (file_exists('/tmp/firmware.upgrade')) {
	@unlink('/tmp/gui_ready');
}

if (PHP_VERSION == '5.2.6' && !is_file("/tmp/gui_ready")){
	print("<html><head><title>beroNet Gateway</title></head>"
		. "<body><div style='text-align:center'>"
		. "<img src='./includes/images/waitlogo.gif' title='Wait image'>"
		. "<p>Please wait until the start process has finished completely.</p>"
		. "</div>"
		. "<script type='text/javascript'>"
		. "window.setTimeout('location.reload()',5000);"
        . "</script></body></html>");
	return;
}

require_once('includes/variables.php');
include_once("/usr/www/include/SQLite2ToSQLite3.php");
require_once('includes/password_func.php');

/* require 'misc/database.php' leads to also load the Helper Class ... why ?? */
require_once('misc/database.php');
require_once('/usr/fallback/beroConf.php');
$bc = new beroConf('root');

// check the request uri entry to forbid <script> and <javascript> flags
if (!Helper::checkInputData('uri', $_SERVER['REQUEST_URI'])) {
	$_SESSION['forbidden_request'] = true;
	include('/usr/local/www/berogui/includes/session.php');
}

// if force https is enabled, do not allow regular http (maybe better to disable port 80?)
if ($bc->get('root', 'httpsOnly') == '1' && !isset($_SERVER['HTTPS']) ) {
	header('Location: https://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']);
	exit;
}

$class = ((isset($_GET['m']) && $_GET['m'] !== '') ? Helper::sanitizeGet($_GET['m'], 'm') : 'State');

$_GET['m'] = $class;
require_once("/usr/local/www/berogui/modules/$class/$class.php");
$instance=new $class($class, $_GET, $_POST, $_SESSION);
print $instance->display();


/* Überprüfung ab eine Hardwareänderung stattgefunden hat,
 * Der Benutzer wird durch eine Meldung darauf hingewiesen,
 * dass ein Factory reset erforderlich ist
 */

$ba = new beroAri();
$revision = Helper::getRevision();
$lif = Helper::getLif();

if (in_array($revision, array('1.8', '1.80')) && (in_array($li[0], array('bf2S02FXS', 'bf4FXS')) || in_array($li[1], array('bf2S02FXS', 'bf4FXS')))) {
	print ("<script>document.getElementById('hardware_ch').innerHTML+=\" ".HARDWARE_SUPPORT_DIS."\";</script>");
}
for ($i = 0; $i < Helper::getLifCount(); $i++) {
	if (hwchange($ba, $i, $lif[$i])) {
		print("<script>document.getElementById('hardware_ch').innerHTML=\"".HARDWARE_CHANGED_DIS."\";</script>");
	}
}
if (Helper::getResetJumper() == 1){
	print ("<script>document.getElementById('reset_jumper').innerHTML=\"".RESET_JUMPER_GUI_DIS."\";</script>");
}

$destination = base64_encode("/app/berogui/index.php?m=$class");
ob_start();

?>
	<script>
		function session(){
			$.ajax({
				url: 'misc/checkSession.php?return=true',
				timeout: 5000,
				success: function(data) {
					var url = data;
					if (url!='')
						window.location=url;
				},
				error: function(res) {
					if (res.status == 408) {
						window.location.href = './includes/login.php?reason=sess_expd&destination=<?php echo $destination; ?>';
					}
				},
			});
		}
	</script>
<?php
print ob_get_clean();

if (strlen($bc->get('root', 'trace-state')) > 0 && $class != 'FulltraceGui') {
	ob_start();
?>
	<script>
		var intervalId = setInterval(debugFilesNotification, 1000);
		function debugFilesNotification() {
			$.ajax({
				data: {
					action: 'notif',
				},
				error: function(res) {
					if (res.status == 400) {
						$('#ajaxErrors').html('<?php echo AJAX_ERRORS_BAD_REQUEST; ?>');
					}
					else if (res.status == 408) {
						window.location.href = './includes/login.php?reason=sess_expd&destination=<?php echo $destination; ?>';
					}
				},
				success: function(res) {
					var state = JSON.parse(res);
					if (typeof state.show !== 'undefined') {
						if (state.show == '1') {
							$('h1').css('margin-bottom', '-10px');
							$('#showNotif').attr('style', 'position:relative;left:69%;top:-25%;color:red;');
							$('#showNotif').html("<?php echo FULL_TRACE_DEBUGFILES_NOTIF; ?>");
							clearInterval(intervalId);
							window.setInterval(session, 10000);
							return;
						}
					}
				},
				timeout: 1000,
				type: 'POST',
				url: 'modules/FulltraceGui/fulltracegui_ajax.php',
			});
		}
	</script>
<?php
}
else {
	ob_start();
?>
	<script>
		window.setInterval(session, 60000);
	</script>
<?php
}
print ob_get_clean();


chdir('/usr/local/www/berogui');
$helpPath="./includes/images/";
require_once('includes/footer.php');
?>
